==> jc-1.4.0.tar.gz: soot/coffi/field__5finfo.h <==
// public class soot.coffi.field_info

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 760b1468884dccc3 soot_coffi_field__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_field__5finfo_H_
#define _JC_soot_coffi_field__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ConstantValue__5fattribute$object;

// Typedefs
typedef struct _jc_soot_coffi_field__5finfo$sub_refs	_jc_soot_coffi_field__5finfo$sub_refs;
typedef struct _jc_soot_coffi_field__5finfo$sub_nonrefs	_jc_soot_coffi_field__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_field__5finfo$refs	_jc_soot_coffi_field__5finfo$refs;
typedef struct _jc_soot_coffi_field__5finfo$nonrefs	_jc_soot_coffi_field__5finfo$nonrefs;
typedef struct _jc_soot_coffi_field__5finfo$object	_jc_soot_coffi_field__5finfo$object;

typedef const struct _jc_soot_coffi_field__5finfo$vmethods	_jc_soot_coffi_field__5finfo$vmethods;
typedef const struct _jc_soot_coffi_field__5finfo$vtable	_jc_soot_coffi_field__5finfo$vtable;
typedef const struct _jc_soot_coffi_field__5finfo$vtype	_jc_soot_coffi_field__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_field__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *);

// Virtual methods
extern struct _jc_soot_coffi_ConstantValue__5fattribute$object *_jc_soot_coffi_field__5finfo$method$findConstantValue__5fattribute$ab74034c70e8ef08(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_field__5finfo$method$prototype$fc9bbd112c759615(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *);
extern struct _jc_java_lang_String$object *_jc_soot_coffi_field__5finfo$method$toName$f6140eb5ad286203(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$findConstantValue__5fattribute$ab74034c70e8ef08;
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$prototype$fc9bbd112c759615;
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$toName$f6140eb5ad286203;

// Virtual methods structure
struct _jc_soot_coffi_field__5finfo$vmethods {
	struct _jc_soot_coffi_ConstantValue__5fattribute$object	*(*findConstantValue__5fattribute$ab74034c70e8ef08)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *);
	struct _jc_java_lang_String$object	*(*prototype$fc9bbd112c759615)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *);
	struct _jc_java_lang_String$object	*(*toName$f6140eb5ad286203)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_soot_coffi_field__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_field__5finfo$vmethods	soot_coffi_field__5finfo;
};

// Vtype
struct _jc_soot_coffi_field__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_field__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_field__5finfo$sub_refs {
	_jc_object_array	*attributes;
};

// Reference instance fields (object)
struct _jc_soot_coffi_field__5finfo$refs {
    _jc_soot_coffi_field__5finfo$sub_refs	soot_coffi_field__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_field__5finfo$sub_nonrefs {
	jint	access__5fflags;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	attributes__5fcount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_field__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_field__5finfo$sub_nonrefs	soot_coffi_field__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_field__5finfo$object {
	_jc_soot_coffi_field__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_field__5finfo$vtype	*vtype;
	_jc_soot_coffi_field__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_field__5finfo$vtype _jc_soot_coffi_field__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_field__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_field__5finfo$class_object;

#endif	/* _JC_soot_coffi_field__5finfo_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/field__5finfo.h <==
// public class soot.coffi.field_info

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 760b1468884dccc3 soot_coffi_field__5finfo

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_coffi_field__5finfo_H_
#define _JC_soot_coffi_field__5finfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_coffi_ConstantValue__5fattribute$object;

// Typedefs
typedef struct _jc_soot_coffi_field__5finfo$sub_refs	_jc_soot_coffi_field__5finfo$sub_refs;
typedef struct _jc_soot_coffi_field__5finfo$sub_nonrefs	_jc_soot_coffi_field__5finfo$sub_nonrefs;
typedef struct _jc_soot_coffi_field__5finfo$refs	_jc_soot_coffi_field__5finfo$refs;
typedef struct _jc_soot_coffi_field__5finfo$nonrefs	_jc_soot_coffi_field__5finfo$nonrefs;
typedef struct _jc_soot_coffi_field__5finfo$object	_jc_soot_coffi_field__5finfo$object;

typedef const struct _jc_soot_coffi_field__5finfo$vmethods	_jc_soot_coffi_field__5finfo$vmethods;
typedef const struct _jc_soot_coffi_field__5finfo$vtable	_jc_soot_coffi_field__5finfo$vtable;
typedef const struct _jc_soot_coffi_field__5finfo$vtype	_jc_soot_coffi_field__5finfo$vtype;

// Constructors
extern void _jc_soot_coffi_field__5finfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_coffi_ConstantValue__5fattribute$object *_jc_soot_coffi_field__5finfo$method$findConstantValue__5fattribute$ab74034c70e8ef08(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_field__5finfo$method$prototype$fc9bbd112c759615(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_coffi_field__5finfo$method$toName$f6140eb5ad286203(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$findConstantValue__5fattribute$ab74034c70e8ef08;
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$prototype$fc9bbd112c759615;
extern _jc_method _jc_soot_coffi_field__5finfo$method_info$toName$f6140eb5ad286203;

// Virtual methods structure
struct _jc_soot_coffi_field__5finfo$vmethods {
	struct _jc_soot_coffi_ConstantValue__5fattribute$object	*(*findConstantValue__5fattribute$ab74034c70e8ef08)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*prototype$fc9bbd112c759615)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toName$f6140eb5ad286203)(_jc_env *, struct _jc_soot_coffi_field__5finfo$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_coffi_field__5finfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_field__5finfo$vmethods	soot_coffi_field__5finfo;
};

// Vtype
struct _jc_soot_coffi_field__5finfo$vtype {
	_jc_type			type;
	_jc_soot_coffi_field__5finfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_field__5finfo$sub_refs {
	_jc_object_array	*attributes;
};

// Reference instance fields (object)
struct _jc_soot_coffi_field__5finfo$refs {
    _jc_soot_coffi_field__5finfo$sub_refs	soot_coffi_field__5finfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_field__5finfo$sub_nonrefs {
	jint	access__5fflags;
	jint	name__5findex;
	jint	descriptor__5findex;
	jint	attributes__5fcount;
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_field__5finfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_field__5finfo$sub_nonrefs	soot_coffi_field__5finfo;
};

// Object instance structure
struct _jc_soot_coffi_field__5finfo$object {
	_jc_soot_coffi_field__5finfo$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_field__5finfo$vtype	*vtype;
	_jc_soot_coffi_field__5finfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_field__5finfo$vtype _jc_soot_coffi_field__5finfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_field__5finfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_field__5finfo$class_object;

#endif	/* _JC_soot_coffi_field__5finfo_H_ */
